@@ -6,6 +6,7 @@
 #include <Convert.h>
 #include <Library/BaseMemoryLib.h>
 #include <Library/PrintLib.h>
+#include <Library/HiiLib.h>
 
 /**
   Convert GUID structure to string
@@ -903,6 +904,12 @@ MakeCapacityString (
     goto Finish;
   }
 
+  // Check if field is unknown (PMTT table is missing). If so, use "Unknown" instead
+  if (Capacity == ACPI_TABLE_VALUE_UNKNOWN) {
+    *ppCapacityStr = HiiGetString(HiiHandle, STRING_TOKEN(STR_UNKNOWN), NULL);
+    goto Finish;
+  }
+
   /** Get the best way to display the capacity if the request is AUTO/AUTO_10 **/
   if ((CurrentUnits == DISPLAY_SIZE_UNIT_AUTO) ||
       (CurrentUnits == DISPLAY_SIZE_UNIT_AUTO_10)) {
