@@ -603,6 +603,10 @@ typedef struct _MEMORY_RESOURCES_INFO {
   UINT64 Reserved2[5];
 } MEMORY_RESOURCES_INFO;
 
+// Hard to accidentally get 0xFFFFFFFF in practice, so it's a reasonable
+// unknown value indicator
+#define ACPI_TABLE_VALUE_UNKNOWN MAX_UINT64_VALUE
+
 typedef struct _DIMM_PERFORMANCE_DATA {
   UINT16  DimmId;             //!< SMBIOS Type 17 handle corresponding to this memory device
   UINT128 MediaReads;         //!< Number of 64 byte reads from media on the PMem module since last AC cycle
